@@ -1,4 +1,5 @@
 #![no_std]
+#![feature(doc_cfg)]
 #![feature(core_intrinsics)]
 #![feature(const_fn)]
 #![feature(const_generics)]
@@ -6,7 +7,15 @@
 #![feature(maybe_uninit_extra)]
 #![feature(exact_size_is_empty)]
 
-use crate::{iterators::*, utils::*};
+//Literally just for stable-sort.
+#[cfg(feature = "std")]
+extern crate alloc;
+
+#[cfg(rustdoc)]
+use alloc::vec::Vec;
+
+pub use crate::iterators::*;
+use crate::utils::*;
 use core::cmp::{Ord, PartialEq};
 use core::iter::FromIterator;
 use core::marker::PhantomData;
@@ -14,13 +23,6 @@ use core::mem::MaybeUninit;
 use core::ops::{Bound::Excluded, Bound::Included, Bound::Unbounded, Index, IndexMut, RangeBounds};
 use core::ptr;
 
-#[cfg(feature = "std")]
-mod std_items {
-  extern crate alloc;
-  #[allow(unused_imports)]
-  use alloc::vec::Vec;
-}
-
 mod iterators;
 mod macros;
 mod utils;
@@ -273,7 +275,7 @@ impl<T, const N: usize> StaticVec<T, {N}> {
   ///and [Ord](core::cmp::Ord) to make the sorting possible.
   #[cfg(feature = "std")]
   #[inline]
-  pub fn sorted(&mut self) -> Self
+  pub fn sorted(&self) -> Self
   where T: Copy + Ord {
     unsafe {
       let mut res = Self::new();
@@ -291,7 +293,7 @@ impl<T, const N: usize> StaticVec<T, {N}> {
   ///Locally requires that `T` implements [Copy](core::marker::Copy) to avoid soundness issues,
   ///and [Ord](core::cmp::Ord) to make the sorting possible.
   #[inline]
-  pub fn sorted_unstable(&mut self) -> Self
+  pub fn sorted_unstable(&self) -> Self
   where T: Copy + Ord {
     unsafe {
       let mut res = Self::new();
@@ -308,7 +310,7 @@ impl<T, const N: usize> StaticVec<T, {N}> {
   ///inhabited area without modifying the original data.
   ///Locally requires that `T` implements [Copy](core::marker::Copy) to avoid soundness issues.
   #[inline]
-  pub fn reversed(&mut self) -> Self
+  pub fn reversed(&self) -> Self
   where T: Copy {
     let mut res = Self::new();
     res.length = self.length;
